# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.0.1](https://github.com/git-afsantos/bake-a-py/releases/tag/v0.0.1) - 2021-12-16
### Added
- Support for type checking with `mypy`.
- Support for code style with `flake8`, `black` and `isort`.
- Configuration for `pre-commit` hooks.
- Example `main` entry point.
- GitHub workflows.

### Changed
- Refining package structure.

### Fixed
- Fixed an issue that prevented `pip install -e .` from working.

## [0.0.0](https://github.com/git-afsantos/bake-a-py/releases/tag/v0.0.0) - 2021-12-09
Repository creation.
